==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/VariableLocationSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.value.V_VARSet;
import io.ciera.tool.sql.ooaofooa.value.VariableLocation;
import io.ciera.tool.sql.ooaofooa.value.VariableLocationSet;
import io.ciera.tool.sql.ooaofooa.value.impl.V_VARSetImpl;

import java.util.Arrays;
import java.util.List;


public class VariableLocationSetImpl extends InstanceSet<VariableLocationSet,VariableLocation> implements VariableLocationSet {

    // attributes
    @Override
    public void setEndPosition( int m_EndPosition ) throws XtumlException {
        for ( VariableLocation variablelocation : this ) variablelocation.setEndPosition( m_EndPosition );
    }
    @Override
    public void setStartPosition( int m_StartPosition ) throws XtumlException {
        for ( VariableLocation variablelocation : this ) variablelocation.setStartPosition( m_StartPosition );
    }
    @Override
    public void setVar_ID( UniqueId ref_Var_ID ) throws XtumlException {
        for ( VariableLocation variablelocation : this ) variablelocation.setVar_ID( ref_Var_ID );
    }
    @Override
    public void setLineNumber( int m_LineNumber ) throws XtumlException {
        for ( VariableLocation variablelocation : this ) variablelocation.setLineNumber( m_LineNumber );
    }
    @Override
    public void setId( UniqueId m_Id ) throws XtumlException {
        for ( VariableLocation variablelocation : this ) variablelocation.setId( m_Id );
    }


    // selections
    @Override
    public V_VARSet R835_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( VariableLocation variablelocation : this ) v_varset.add( variablelocation.R835_V_VAR() );
        return v_varset;
    }


    @Override
    public VariableLocation nullElement() {
        return VariableLocationImpl.EMPTY_VARIABLELOCATION;
    }

    @Override
    public VariableLocationSet emptySet() {
      return new VariableLocationSetImpl();
    }

    @Override
    public VariableLocationSet value() {
        return this;
    }

    @Override
    public List<VariableLocation> elements() {
        return Arrays.asList(toArray(new VariableLocation[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/VariableLocationSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.value.V_VARSet;
import io.ciera.tool.sql.ooaofooa.value.VariableLocation;
import io.ciera.tool.sql.ooaofooa.value.VariableLocationSet;
import io.ciera.tool.sql.ooaofooa.value.impl.V_VARSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class VariableLocationSetImpl extends InstanceSet<VariableLocationSet,VariableLocation> implements VariableLocationSet {

    public VariableLocationSetImpl() {
    }

    public VariableLocationSetImpl(Comparator<? super VariableLocation> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setVar_ID( UniqueId ref_Var_ID ) throws XtumlException {
        for ( VariableLocation variablelocation : this ) variablelocation.setVar_ID( ref_Var_ID );
    }
    @Override
    public void setId( UniqueId m_Id ) throws XtumlException {
        for ( VariableLocation variablelocation : this ) variablelocation.setId( m_Id );
    }
    @Override
    public void setLineNumber( int m_LineNumber ) throws XtumlException {
        for ( VariableLocation variablelocation : this ) variablelocation.setLineNumber( m_LineNumber );
    }
    @Override
    public void setStartPosition( int m_StartPosition ) throws XtumlException {
        for ( VariableLocation variablelocation : this ) variablelocation.setStartPosition( m_StartPosition );
    }
    @Override
    public void setEndPosition( int m_EndPosition ) throws XtumlException {
        for ( VariableLocation variablelocation : this ) variablelocation.setEndPosition( m_EndPosition );
    }


    // selections
    @Override
    public V_VARSet R835_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( VariableLocation variablelocation : this ) v_varset.add( variablelocation.R835_V_VAR() );
        return v_varset;
    }


    @Override
    public VariableLocation nullElement() {
        return VariableLocationImpl.EMPTY_VARIABLELOCATION;
    }

    @Override
    public VariableLocationSet emptySet() {
      return new VariableLocationSetImpl();
    }

    @Override
    public VariableLocationSet emptySet(Comparator<? super VariableLocation> comp) {
      return new VariableLocationSetImpl(comp);
    }

    @Override
    public VariableLocationSet value() {
        return this;
    }

    @Override
    public List<VariableLocation> elements() {
        return Arrays.asList(toArray(new VariableLocation[0]));
    }

}
